@@ -1,7 +1,7 @@
 /* io.c: i/o routines for the ed line editor */
 /* GNU ed - The GNU line editor.
    Copyright (C) 1993, 1994 Andrew L. Moore, Talke Studio
-   Copyright (C) 2006-2024 Antonio Diaz Diaz.
+   Copyright (C) 2006-2025 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -19,21 +19,19 @@
 
 #include <errno.h>
 #include <stdio.h>
-#include <stdlib.h>
 #include <string.h>
-#include <sys/stat.h>
 
 #include "ed.h"
 
 
-static const line_t * unterminated_line = 0;	/* last line has no '\n' */
+static const line_node * unterminated_line = 0;	/* last line has no '\n' */
 static int linenum_ = 0;			/* script line number */
 
 int linenum( void ) { return linenum_; }
 
 void reset_unterminated_line( void ) { unterminated_line = 0; }
 
-void unmark_unterminated_line( const line_t * const lp )
+void unmark_unterminated_line( const line_node * const lp )
   { if( unterminated_line == lp ) unterminated_line = 0; }
 
 static bool unterminated_last_line( void )
@@ -82,8 +80,8 @@ static void print_line( const char * p, int len, const int pflags )
 /* print a range of lines to stdout */
 bool print_lines( int from, const int to, const int pflags )
   {
-  line_t * const ep = search_line_node( inc_addr( to ) );
-  line_t * bp = search_line_node( from );
+  line_node * const ep = search_line_node( inc_addr( to ) );
+  line_node * bp = search_line_node( from );
 
   if( !from ) { invalid_address(); return false; }
   while( bp != ep )
@@ -236,8 +234,8 @@ static const char * read_stream_line( const char * const filename,
 static long read_stream( const char * const filename, FILE * const fp,
                          const int addr )
   {
-  line_t * lp = search_line_node( addr );
-  undo_t * up = 0;
+  line_node * lp = search_line_node( addr );
+  undo_atom * up = 0;
   long total_size = 0;		/* number of bytes read */
   const bool o_isbinary = isbinary();
   const bool appended = ( addr == last_addr() );
@@ -265,10 +263,11 @@ static long read_stream( const char * const filename, FILE * const fp,
       }
     enable_interrupts();
     }
-  if( addr && appended && total_size && o_unterminated_last_line )
-    fputs( "Newline inserted\n", stdout );		/* before stream */
-  else if( newline_added && ( !appended || !isbinary() ) )
-    fputs( "Newline appended\n", stdout );		/* after stream */
+  if( !scripted() )
+    { if( addr && appended && total_size && o_unterminated_last_line )
+        fputs( "Newline inserted\n", stdout );		/* before stream */
+      else if( newline_added && ( !appended || !isbinary() ) )
+        fputs( "Newline appended\n", stdout ); }	/* after stream */
   if( !appended && isbinary() && !o_isbinary && newline_added )
     ++total_size;
   if( appended && isbinary() && ( newline_added || total_size == 0 ) )
@@ -291,64 +290,26 @@ int read_file( const char * const filename, const int addr,
            ( fp = fopen( filename, "r" ) ) && read_onlyp && !modified() )
     *read_onlyp = true;
   if( !fp )
-    {
-    show_strerror( filename, errno );
-    set_error_msg( "Cannot open input file" );
-    return -1;
-    }
+    { show_strerror( filename, errno );
+      set_error_msg( "Cannot open input file" ); return -1; }
   const long size = read_stream( filename, fp, addr );	/* file size in bytes */
   if( *filename == '!' ) ret = pclose( fp ); else ret = fclose( fp );
   if( size < 0 ) return -2;
-  if( ret != 0 )
-    {
-    show_strerror( filename, errno );
-    set_error_msg( "Cannot close input file" );
-    return -2;
-    }
+  if( ret < 0 )
+    { show_strerror( filename, errno );
+      set_error_msg( "Cannot close input file" ); return -2; }
   if( !scripted() ) printf( "%lu\n", size );
   return current_addr() - addr;	/* current_addr updated by add_line_node */
   }
 
 
-static bool make_dirs( const char * const name )
-  {
-  int i = strlen( name );
-  while( i > 0 && name[i-1] != '/' ) --i;	/* remove last component */
-  while( i > 0 && name[i-1] == '/' ) --i;	/* remove slash(es) */
-  if( i <= 0 ) return true;			/* dirname is '/' or empty */
-  const int dirsize = i;	/* size of dirname without trailing slash */
-  char * const partial = (char *)malloc( dirsize + 1 );
-  if( !partial ) return false;
-
-  for( i = 0; i < dirsize; )
-    {
-    while( i < dirsize && name[i] == '/' ) ++i;
-    const int first = i;
-    while( i < dirsize && name[i] != '/' ) ++i;
-    if( first < i )
-      {
-      memcpy( partial, name, i ); partial[i] = 0;
-      const unsigned mode = S_IRWXU | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH;
-      struct stat st;
-      if( stat( partial, &st ) == 0 )
-        { if( !S_ISDIR( st.st_mode ) )
-            { free( partial ); errno = ENOTDIR; return false; } }
-      else if( mkdir( partial, mode ) != 0 && errno != EEXIST )
-        { free( partial ); return false; }
-      /* if EEXIST, another process created the dir */
-      }
-    }
-  free( partial ); return true;
-  }
-
-
 /* Write a range of lines to a stream.
    Return number of bytes written, or -1 if error.
 */
 static long write_stream( const char * const filename, FILE * const fp,
                           int from, const int to )
   {
-  line_t * lp = search_line_node( from );
+  line_node * lp = search_line_node( from );
   long size = 0;		/* number of bytes written */
 
   while( from && from <= to )
@@ -383,20 +344,14 @@ int write_file( const char * const filename, const char * const mode,
   int ret;
 
   if( *filename == '!' ) fp = popen( filename + 1, "w" );
-  else
-    {
-    if( !make_dirs( filename ) )
-      { show_strerror( filename, errno );
-        set_error_msg( "Error creating intermediate directory" ); return -1; }
-    fp = fopen( filename, mode );
-    }
+  else fp = fopen( filename, mode );
   if( !fp )
     { show_strerror( filename, errno );
       set_error_msg( "Cannot open output file" ); return -1; }
   const long size = write_stream( filename, fp, from, to );	/* bytes written */
   if( *filename == '!' ) ret = pclose( fp ); else ret = fclose( fp );
   if( size < 0 ) return -1;
-  if( ret != 0 )
+  if( ret < 0 )
     { show_strerror( filename, errno );
       set_error_msg( "Cannot close output file" ); return -1; }
   if( !scripted() ) printf( "%lu\n", size );
